import sys
import re
import requests
import sqlite3

from ics import Calendar

url: str = "https://adecons.unistra.fr/jsp/custom/modules/plannings/anonymous_cal.jsp?resources=5242&projectId=8&calType=ical&nbWeeks=4"
database = sqlite3.connect("assets/ufhour.sqlite")

rooms_tp = [
    ('T01', 0, 0),
    ('T02', 0, 0),
    ('T03', 0, 0),
    ('T11', 0, 1),
    ('T20', 0, 2),
    ('T21', 0, 2),
    ('T22', 0, 2),
    ('T23', 0, 2),
    ('T24', 0, 2),
]


def main():
    init_tables()
    import_schedule()


def import_schedule():
    cursor = database.cursor()
    cal = Calendar(requests.get(url, allow_redirects=True).text)
    events = [(re.match('([A-Z]\d+)', e.location).group(1),
               e.begin.format("DD-MM-YYYY"),
               e.begin.shift(hours=+2).format("HH:mm"),
               e.end.shift(hours=+2).format("HH:mm"))

              for e in cal.events]

    cursor.executemany("INSERT OR IGNORE INTO schedule VALUES (?,?,?,?)", events)
    database.commit()


def init_tables():
    cursor = database.cursor()
    cursor.execute("""CREATE TABLE IF NOT EXISTS rooms (
        id TEXT PRIMARY KEY,
        type INTEGER NOT NULL,
        location INTEGER NOT NULL
    )""")

    cursor.execute("""CREATE TABLE IF NOT EXISTS schedule (
        id TEXT NOT NULL,
        date TEXT NOT NULL,
        start_time TEXT NOT NULL,
        end_time TEXT NOT NULL,
        FOREIGN KEY(id) REFERENCES rooms(id)
    )""")

    cursor.executemany("INSERT OR IGNORE INTO rooms VALUES (?,?,?)", rooms_tp)
    database.commit()


if __name__ == "__main__":
    main()
